@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 require XSLoader;
 XSLoader::load('Ganglia::Gmetric::XS', $VERSION);
@@ -14,7 +14,8 @@ sub new {
     my %args  = @_;
 
     my $config = delete $args{config} || "/etc/gmond.conf";
-    return _ganglia_initialize($class, $config);
+    my $spoof = delete $args{spoof};
+    return _ganglia_initialize($class, $config, $spoof);
 }
 
 sub send {
@@ -23,13 +24,24 @@ sub send {
     return _ganglia_send(
         $self,
         $args{name}  || "",
-        $args{value} || "",
+        exists $args{value} ? $args{value} : "",
         $args{type}  || "",
         $args{units} || "",
         $args{group} || "",
         $args{desc}  || "",
         $args{title} || "",
-        3, 60, 0);
+        3, 60, 0,
+        $args{spoof} || "",
+    );
+}
+
+sub heartbeat {
+    my ($self, %args) = @_;
+
+    return _ganglia_heartbeat(
+        $self,
+        $args{spoof} || "",
+    );
 }
 
 1;
@@ -51,6 +63,15 @@ Ganglia::Gmetric::XS - send a metric value to gmond with libganglia C library
               units => "connection",
              );
 
+
+
+    my $gg = Ganglia::Gmetric::XS->new(
+        config => "/etc/gmond.conf",
+        spoof => 'aServer:192.168.1.3'
+    );
+    $gg->heartbeat();
+
+
 =head1 DESCRIPTION
 
 Ganglia::Gmetric::XS can send a metric value to gmond with libganglia
@@ -63,17 +84,26 @@ C library.
   $gg = Ganglia::Gmetric::XS->new( %option );
 
 This method constructs a new "Ganglia::Gmetric::XS" instance and
-returns it. %option is following:
+returns it. %option may have the following keys:
 
-  KEY    VALUE
-  ----------------------------
-  config "/etc/gmond.conf"
+=over
+
+=item config
+
+Example: "/etc/gmond.conf" - The configuration file to use for finding send channels
+
+=item spoof
+
+If this object should spoof every metric value sent to gmond, then the
+spoof IP Address and hostname (colon separated) may be specified here.
+
+=back
 
 =head2 send
 
   $gg->send( %param ) or carp "failed to send metric";
 
-do send a metric value. %param is following:
+send a metric value. %param is following:
 
   KEY    VALUE
   ----------------------------
@@ -84,6 +114,21 @@ do send a metric value. %param is following:
   group  group name of metric. (optional)
   desc   description of metric. (optional)
   title  title of metric. (optional)
+  spoof  IP address and hostname (colon separated) of the host to spoof (optional)
+
+=head2 heartbeat
+
+  $gg->heartbeat( %param )
+
+If you are spoofing the existence of a host, you will need to
+periodically send heartbeat messages to tell gmond that the host is
+up.
+
+send a heartbeat. %param is following:
+
+  KEY    VALUE
+  ----------------------------
+  spoof  IP address and hostname (colon separated) of the host to spoof (optional)
 
 =head1 SEE ALSO
 
